==> phantom-dsl_2.10-1.26.1-sources.jar: com/websudos/phantom/builder/serializers/DeleteQueryBuilder.scala <==
/*
 * Copyright 2013-2015 Websudos, Limited.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * - Explicit consent must be obtained from the copyright owner, Outworkers Limited before any redistribution is made.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.websudos.phantom.builder.serializers

import com.websudos.phantom.builder.query.CQLQuery
import com.websudos.phantom.builder.syntax.CQLSyntax

private[builder] class DeleteQueryBuilder {
  def delete(table: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def delete(table: String, cond: CQLQuery): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(cond)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def deleteColumn(table: String, column: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(column)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def deleteMapColumn(table: String, column: String, key: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(qUtils.mapKey(column, key))
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }
}

==> phantom-dsl_2.10-1.28.13-sources.jar: com/websudos/phantom/builder/serializers/DeleteQueryBuilder.scala <==
/*
 * Copyright 2013-2015 Websudos, Limited.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * - Explicit consent must be obtained from the copyright owner, Outworkers Limited before any redistribution is made.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.websudos.phantom.builder.serializers

import com.websudos.phantom.builder.query.CQLQuery
import com.websudos.phantom.builder.syntax.CQLSyntax

private[builder] class DeleteQueryBuilder {
  def delete(table: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def delete(table: String, cond: CQLQuery): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(cond)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def delete(table: String, conds: Seq[CQLQuery]): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(conds.map(_.queryString))
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def deleteColumn(table: String, column: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(column)
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }

  def deleteMapColumn(table: String, column: String, key: String): CQLQuery = {
    CQLQuery(CQLSyntax.delete)
      .forcePad.append(qUtils.mapKey(column, key))
      .forcePad.append(CQLSyntax.from)
      .forcePad.append(table)
  }
}
